#!/bin/sh

GC_BIN="opt/gnome/bin/gconftool-2"
PATH_SCHEMAS="etc/gnome/gconf/schemas"

config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
    rm $NEW
  fi
}

removegconf() {
   if [ -x ${GC_BIN} ]; then
      export GCONF_CONFIG_SOURCE=$(${GC_BIN} --get-default-source)
      if [ -f ${PATH_SCHEMAS}/${1}.schemas ]; then
         echo "Rimozione dello schema per $1..."
         ${GC_BIN} --makefile-uninstall-rule \
            ${PATH_SCHEMAS}/${1}.schemas 1>/dev/null
      fi
   fi
}

updategconf() {
   if [ -x ${GC_BIN} ]; then
      export GCONF_CONFIG_SOURCE=$(${GC_BIN} --get-default-source)
      if [ -f ${PATH_SCHEMAS}/${1}.schemas ]; then
         echo "Installazione dello schema per $1..."
         ${GC_BIN} --makefile-install-rule \
            ${PATH_SCHEMAS}/${1}.schemas 1>/dev/null
      fi
   fi
}

updategconfex() {
   if [ -x ${GC_BIN} ]; then
      local entries="etc/gnome/gconf/schemas/panel-default-setup.entries"
      export GCONF_CONFIG_SOURCE=$(${GC_BIN} --get-default-source)
      echo "Installazione dello schema di default..."
      ${GC_BIN} --direct --config-source \
         ${GCONF_CONFIG_SOURCE} --load=${entries} 1>/dev/null
   fi
}

updatekeeper() {
   if [ -x usr/bin/scrollkeeper-update -a -d var/lib/scrollkeeper ]; then
      echo "Aggiornamento indice scrollkeeper..."
      usr/bin/scrollkeeper-update -q -p var/lib/scrollkeeper
   fi
}

updateicons() {
   if [ -x usr/bin/gtk-update-icon-cache -a -d usr/share/icons ]; then
      echo "Aggiornamento della cache delle icone..."
      for dir in $(find usr/share/icons -maxdepth 1 -mindepth 1 -type d); do
         if [ -f "${dir}/index.theme" ]; then
            usr/bin/gtk-update-icon-cache -qf ${dir}
         fi
      done
   fi
}

updatemime() {
   if [ -x usr/bin/update-mime-database -a -d usr/share/mime ]; then
      echo "Aggiornamento dei tipi mime..."
      usr/bin/update-mime-database usr/share/mime
   fi
}

updatedesktop() {
   if [ -x usr/bin/update-desktop-database ]; then
      echo "Aggiornamento dei menu del desktop..."
      usr/bin/update-desktop-database
   fi
}

updatescrolldocs() {
   if [ -f tmp/rgplist -a -f var/lib/scrollkeeper/scrollkeeper_docs ]; then
      if [ -x usr/bin/scrollkeeper-uninstall ]; then
         echo "Rimozione vecchi file dal catalogo di scrollkeeper..."
         for files in $(cat tmp/rgplist); do
            usr/bin/scrollkeeper-uninstall $files > /dev/null
         done
      fi
      rm -f tmp/rgplist
   fi
   if [ -f tmp/rgpdocs -a -f var/lib/scrollkeeper/scrollkeeper_docs ]; then
      echo "Aggiornamento catalogo di scrollkeeper..."
      cat tmp/rgpdocs >> var/lib/scrollkeeper/scrollkeeper_docs
      rm -f tmp/rgpdocs
      updatekeeper
   fi
}

reloadgconfd() {
   pids=$(pidof gconfd-2)
   if [ $? == 0 ]; then
      echo "Riavvio del server gconf..."
      kill -HUP ${pids}
   fi
}

   
